# -*- coding: utf-8 -*-

"""Test that all modules are importable.
"""

import yamldirs
import yamldirs.filemaker
import yamldirs.yamldirs_cmd


def test_import_():
    "Test that all modules are importable."
    
    assert yamldirs
    assert yamldirs.filemaker
    assert yamldirs.yamldirs_cmd



from __future__ import print_function
import os
import tempfile
from contextlib import contextmanager


def test_cd_to_tempdir():
    """Test basic temp dir functionality.
    """
    initial_cwd = os.getcwd()
    abspath_tmpdir = os.path.realpath(tempfile.mkdtemp())
    try:
        assert os.path.isabs(abspath_tmpdir)
        os.chdir(abspath_tmpdir)
        curdir = os.getcwd()
        assert initial_cwd != curdir
        assert curdir == abspath_tmpdir
    finally:
        os.chdir(initial_cwd)      # must exit directory..
        os.rmdir(abspath_tmpdir)  # ..before it can be removed


@contextmanager
def tempdir():
    cwd = os.getcwd()
    tmpdir = os.path.realpath(tempfile.mkdtemp())
    try:
        os.chdir(tmpdir)
        yield tmpdir
    finally:
        os.chdir(cwd)
        os.rmdir(tmpdir)


def test_tempdir_context():
    cwd = os.getcwd()
    with tempdir() as folder:
        assert folder != cwd
        curdir = os.getcwd()
        assert folder == curdir



# -*- coding: utf-8 -*-
from __future__ import print_function

import io
import os
import sys
import textwrap

from tests.testpkg.foo import foo
from yamldirs import create_files
from yamldirs.yamldirs_cmd import main, directory2yaml, reconstitute_directory

DIRNAME = os.path.dirname(__file__)


def test_foo():
    assert foo() == 42


def test_directory2yaml():
    os.chdir(DIRNAME)
    print("DIRNAME:", DIRNAME)
    with io.open('foo.tmp', 'w', encoding='ascii') as fp:
        directory2yaml('testpkg', fp)
    out = io.open('foo.tmp', encoding='ascii').read()
    print("OUT:", out)

    option1 = out == textwrap.dedent(u"""\
        testpkg:
          foo.py: |-
            def foo():
                return 42
          __init__.py: ''
          """)
    option2 = out == textwrap.dedent(u"""\
        testpkg:
          __init__.py: ''
          foo.py: |-
            def foo():
                return 42
          """)
    assert option1 or option2
    os.unlink('foo.tmp')


def test_reconstitute_directory():
    fdef = """
        hello: world
    """
    with create_files(fdef, cleanup=True):
        open('foo.yaml', 'w').write(textwrap.dedent(u"""\
               testpkg:
                  foo.py: |-
                    def foo():
                        return 42
                  __init__.py: ''    
          """))
        reconstitute_directory('foo.yaml')
        assert os.path.exists('testpkg/foo.py')



# -*- coding: utf-8 -*-
from __future__ import print_function

import io
import os
import sys

from ruamel.yaml import YAML
from ruamel.yaml.scalarstring import LiteralScalarString
from .filemaker import Filemaker


def tree(root):
    def _tree():
        for rt, dirs, files in os.walk(root):
            # print(rt, dirs, files)
            for name in files:
                if name.endswith('~'):
                    continue
                if name.startswith('.'):
                    continue
                yield os.path.join(rt, name)
    return list(sorted(_tree()))


def directory2yaml(dirname, stream=sys.stdout):
    res = {}
    for filename in tree(dirname):
        if filename.endswith('.pyc'):
            continue
        parts = filename.replace('\\', '/').split('/')
        cur = res
        for part in parts[:-1]:
            cur.setdefault(part, {})
            cur = cur[part]
        with io.open(filename, 'rb') as fp:
            txt = fp.read()
            # print("TXT:", txt)
            txt = txt.replace(b'\r\n', b'\n').decode('ascii').strip()
        if txt.count('\n') >= 1:
            txt = LiteralScalarString(txt)
        cur[parts[-1]] = txt
    yaml = YAML()
    yaml.default_flow_style = False
    yaml.dump(res, stream)


def reconstitute_directory(yamlfile):
    Filemaker(os.getcwd(), open(yamlfile).read())


def main():     # pragma: nocover
    arg = sys.argv[1]
    if arg.endswith('.yaml'):
        reconstitute_directory(arg)
    else:
        directory2yaml(arg)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""yamldirs - create directories and files (incl. contents) from yaml spec.
"""
import sys
from setuptools import setup, find_packages


classifiers = """\
Development Status :: 5 - Production/Stable
Intended Audience :: Developers
Programming Language :: Python
Programming Language :: Python :: 2
Programming Language :: Python :: 2.7
Programming Language :: Python :: 3
Programming Language :: Python :: 3.5
Programming Language :: Python :: 3.6
Programming Language :: Python :: 3.7
Programming Language :: Python :: 3.8
Topic :: Software Development :: Libraries
"""

version = '1.1.15'


setup(
    name='yamldirs',
    version=version,
    install_requires=[
        'ruamel.yaml'
    ],
    author='Bjorn Pettersen',
    author_email='bp@datakortet.no',
    url='https://github.com/datakortet/yamldirs',
    description=__doc__.strip(),
    classifiers=[line for line in classifiers.split('\n') if line],
    long_description=open('README.rst').read(),
    entry_points={
        'console_scripts': [
            'yamldirs = yamldirs.yamldirs_cmd:main',
        ]
    },
    packages=find_packages(),
    zip_safe=False,
)



# -*- coding: utf-8 -*-
from __future__ import print_function
import os
import textwrap
import warnings

import pytest
from yamldirs import create_files
from yamldirs.filemaker import UnknownType


def tree(root):
    def _tree():
        for rt, dirs, files in os.walk(root):
            for name in files:
                yield os.path.join(rt, name)
    return list(sorted(_tree()))


def test_create_file():
    fdef = """
        foo.txt
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [os.path.join(workdir, 'foo.txt')]
        assert os.path.isfile('foo.txt')
        assert open('foo.txt').read() == ""


def test_number_filenames():
    fdef = """
        2: "hello"
    """
    with create_files(fdef, cleanup=True) as workdir :
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [os.path.join(workdir, '2')]
        assert open(os.path.join(workdir, '2')).read() == 'hello'


def test_date_filenames():
    fdef = """
        2017-10-25: "hello"
    """
    with create_files(fdef, cleanup=True) as workdir :
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [os.path.join(workdir, '2017-10-25')]
        assert open(os.path.join(workdir, '2017-10-25')).read() == 'hello'


def test_date_content():
    fdef = """
        foo: 2017-10-25
    """
    with create_files(fdef, cleanup=True) as workdir :
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [os.path.join(workdir, 'foo')]
        assert open(os.path.join(workdir, 'foo')).read() == '2017-10-25'


def test_unknown_type():
    fdef = """
        - 2017-10-25T12:54:42.1Z
    """
    with pytest.raises(UnknownType):
        with create_files(fdef, cleanup=True) as workdir :
            pass  # pragma: nocover


def test_number_content():
    fdef = """
        2: 3
    """
    with create_files(fdef, cleanup=True) as workdir :
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [os.path.join(workdir, '2')]
        assert open(os.path.join(workdir, '2')).read() == '3'


def test_create_file_content():
    fdef = """
        foo.txt: |
            hello world
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [os.path.join(workdir, 'foo.txt')]
        assert open(os.path.join(workdir, 'foo.txt')).read() == 'hello world\n'


def test_create_file_content2():
    fdef = """
        foo.txt: hello world
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [os.path.join(workdir, 'foo.txt')]
        assert open(os.path.join(workdir, 'foo.txt')).read() == 'hello world'


def test_create_file_multiline_content():
    fdef = """
        foo.txt: |
            Lorem ipsum dolor sit amet, vis no altera doctus sanctus,
            oratio euismod suscipiantur ne vix, no duo inimicus
            adversarium. Et amet errem vis. Aeterno accusamus sed ei,
            id eos inermis epicurei. Quo enim sonet iudico ea, usu
            et possit euismod.
    """
    lorem = textwrap.dedent("""\
        Lorem ipsum dolor sit amet, vis no altera doctus sanctus,
        oratio euismod suscipiantur ne vix, no duo inimicus
        adversarium. Et amet errem vis. Aeterno accusamus sed ei,
        id eos inermis epicurei. Quo enim sonet iudico ea, usu
        et possit euismod.
        """)
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [os.path.join(workdir, 'foo.txt')]
        assert open(os.path.join(workdir, 'foo.txt')).read() == lorem


def test_create_empty_files():
    fdef = """
        - foo.txt
        - bar.txt
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [
            os.path.join(workdir, 'bar.txt'),
            os.path.join(workdir, 'foo.txt')
        ]


def test_create_empty_files2():
    fdef = """
        foo.txt: ""
        bar.txt: ""
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [
            os.path.join(workdir, 'bar.txt'),
            os.path.join(workdir, 'foo.txt')
        ]
        assert open('foo.txt').read() == ""


def test_create_files():
    fdef = """
        - foo.txt: |
            hello
        - bar.txt: |
            world
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [
            os.path.join(workdir, 'bar.txt'),
            os.path.join(workdir, 'foo.txt')
        ]
        assert open(os.path.join(workdir, 'foo.txt')).read() == 'hello\n'
        assert open(os.path.join(workdir, 'bar.txt')).read() == 'world\n'


def test_create_directory():
    fdef = """
        bar:
            - foo.txt
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        assert tree(workdir) == [os.path.join(workdir, 'bar', 'foo.txt')]


def test_mix_empty():
    files = """
        - a.py
        - b:
            - a.txt
            - aa.txt
        - d
        - e:
            - a:
                - b
        - f
    """
    with create_files(files) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        print("LISTDIR:", os.listdir('.'))
        assert {os.path.relpath(d, workdir) for d in os.listdir('.')} == {
            'a.py', 'b', 'd', 'e', 'f'
        }


def test_empty_directory2():
    fdef = """
        bar: []
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        bardir = os.path.join(workdir, 'bar')
        assert os.path.isdir(bardir)
        assert os.listdir(bardir) == []


def test_empty_directoryw():
    fdef = """
        bar:
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        bardir = os.path.join(workdir, 'bar')
        assert os.path.isdir(bardir)
        assert os.listdir(bardir) == []


def test_nested_directory():
    fdef = """
        foo:
            - a
            - bar:
                - b
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        foodir = os.path.join(workdir, 'foo')
        bardir = os.path.join(workdir, 'foo', 'bar')
        assert os.path.isdir(foodir)
        assert os.path.isdir(bardir)
        assert set(os.listdir(foodir)) == {'a', 'bar'}
        assert os.listdir(bardir) == ['b']


def test_nested_directory2():
    fdef = """
        foo:
            bar:
                baz:
                    hello: world
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))

        foodir = os.path.join(workdir, 'foo')
        assert os.path.isdir(foodir)

        bardir = os.path.join(workdir, 'foo', 'bar')
        assert os.path.isdir(bardir)
        assert set(os.listdir(foodir)) == {'bar'}

        bazdir = os.path.join(workdir, 'foo', 'bar', 'baz')
        assert os.path.isdir(bazdir)
        assert os.listdir(bazdir) == ['hello']

        hello = os.path.join(bazdir, 'hello')
        assert os.path.isfile(hello)
        assert open(hello).read() == "world"


def test_nested_directory_json():
    fdef = """
        {
            "foo": [
                "a",
                "bar": ["b"]
            ]
        }
    """
    with create_files(fdef, cleanup=True) as workdir:
        print("WORKDIR:", workdir)
        print(tree(workdir))
        foodir = os.path.join(workdir, 'foo')
        bardir = os.path.join(workdir, 'foo', 'bar')
        assert os.path.isdir(foodir)
        assert os.path.isdir(bardir)
        assert set(os.listdir(foodir)) == {'a', 'bar'}
        assert os.listdir(bardir) == ['b']
